# Python Password Safe

**Python Password Safe** is a simple password manager CLI tool written in Python.

**Python Password Safe** allows you to save an encrypted list of username-password entries organized into different groups of your making. All you have to do is create and remember one master PIN number in order to unlock your password safe.

---

**NOTE**

High-level secureity is not gauranteed. Please use this program at your own risk!

This project was independently made for the purposes of learning new cryptography tools, practicing database interactions with SQLite, and developing a personal password manager for my local machine.

---

## Demo

---

**NOTE**
Colors, emojis, and other formatted text will not display correctly on Windows machines. _Windows Command-Line_ does not (currently) support unicode characters.

---

## Getting Started

### Installation

```
# Using PyPI
pip3 install py-pwsafe
```

### Running the program

```
pypwsafe
```

## License

[![MIT License](https://img.shields.io/apm/l/atomic-design-ui.svg?)](https://github.com/tterb/atomic-design-ui/blob/master/LICENSEs)

Copyright (c) 2020 Ricky Thai
